import java.util.*;

/**
 * Auswertung von arithmetischen Postfix-Ausdruecken.
 * 
 * @version 2007-07-20
 * @author Owyn
 */
public class Postfix {

    /**
     * Wertet einen arithmetischen Ausdruck aus.
     * 
     * @param ausdruck Arithmetischer Ausdruck in Postfix-Schreibweise
     * @return das Ergebnis der Rechnung
     */
    private static int eval(String ausdruck) {
        
        // Ausdruck in Folge von Ziffern, Operatoren und Leerzeichen (jeweils als String) trennen
        StringTokenizer t = new StringTokenizer(ausdruck, " +-*/", true);
        
        // Stack fuer die Auswertung des Ausdrucks
        Stack<Integer> s = new Stack<Integer>();

        while (t.hasMoreTokens()) { // So lange es noch Tokens gibt...
            String token = t.nextToken(); // ...lesen wir einen Token ein...
            char tok = token.charAt(0); // ...und speichern das erste Zeichen als char.
            if (tok >= '0' && tok <= '9') // Wenn dieses eine Ziffer ist, handelt es sich beim Token um eine Zahl...
                s.push(new Integer(token)); // ...die wir als neuen Integer auf den Stack legen.
            else if (tok != ' ') { // Wenn das erste Zeichen weder Ziffer noch Leerzeichen ist, handelt es sich um einen Operator.
                int right = s.pop().intValue(); // Also holen wir den rechten...
                int left = s.pop().intValue(); // ...und dann den linken Operand vom Stack.
                int result = 0;
                switch (tok) { // Je nach Operator speichern wir das Ergebnis der Rechenoperation...
                    case '+': result = left + right; break;
                    case '-': result = left - right; break;
                    case '*': result = left * right; break;
                    case '/': result = left / right; break;
                }
                s.push(new Integer(result)); // ...und legen es als neuen Integer wieder auf den Stack.
            }
        } // An dieser Stelle gibt es keine Tokens mehr...
        return s.pop().intValue(); // ...also liegt das Ergebnis des Ausdrucks als oberstes Element auf dem Stack.
    }
    
    /**
     * Wertet einen arithmetischen Ausdruck aus und gibt das Ergebnis oder eine Fehlermeldung aus.
     * 
     * @param ausdruck Arithmetischer Ausdruck in Postfix-Schreibweise
     */
    public static void postfix(String ausdruck) {
        
        System.out.println(ausdruck + " = " + eval(ausdruck));
        
    }

}